]> git.tuebingen.mpg.de Git - dss.git/blobdiff - snap.h
dss-0.1.3.
[dss.git] / snap.h
diff --git a/snap.h b/snap.h
index 7ac951fc313adb9f0867bc90463d4773f215adb9..0ebc4d28d24f423fc358385225d53d6bc7bdb878 100644 (file)
--- a/snap.h
+++ b/snap.h
@@ -1,39 +1,25 @@
 /*
 /*
- * Copyright (C) 2008 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 2008-2009 Andre Noll <maan@systemlinux.org>
  *
  * Licensed under the GPL v2. For licencing details see COPYING.
  */
 
  *
  * Licensed under the GPL v2. For licencing details see COPYING.
  */
 
-/** The state of snapshot creation. */
-enum {
+/** The possible states for snapshot creation/removal. */
+enum hook_status {
        /** We are ready to take the next snapshot. */
        /** We are ready to take the next snapshot. */
-       SCS_READY,
-       /** The pre-creation hook has been started. */
-       SCS_PRE_HOOK_RUNNING,
-       /** The pre-creation hook exited successfully. */
-       SCS_PRE_HOOK_SUCCESS,
-       /** The rsync process is running. */
-       SCS_RSYNC_RUNNING,
-       /** The rsync process exited successfully. */
-       SCS_RSYNC_SUCCESS,
-       /** The rsync process needs to be restarted. */
-       SCS_RSYNC_NEEDS_RESTART,
-       /** The post-create hook has been started. */
-       SCS_POST_HOOK_RUNNING,
-};
-
-/** The state of snapshot removal. */
-enum {
-       /** No snapshot is currently being removed. */
-       SRS_READY,
-       /** The pre-removal hook has been started. */
-       SRS_PRE_HOOK_RUNNING,
-       /** The pre-remove hook failed, we're waiting to execute it again. */
-       SRS_PRE_HOOK_FAILURE,
-       /** The rm command is currently executing. */
-       SRS_RM_RUNNING,
-       /** The post-remove hook ist running. */
-       SRS_POST_HOOK_RUNNING,
+       HS_READY,
+       /** The pre-create/pre-remove hook has been started. */
+       HS_PRE_RUNNING,
+       /** The pre-create/pre-remove hook exited successfully. */
+       HS_PRE_SUCCESS,
+       /** The rsync/rm process is running. */
+       HS_RUNNING,
+       /** The rsync/rm process exited successfully. */
+       HS_SUCCESS,
+       /** The rsync/rm process needs to be restarted. */
+       HS_NEEDS_RESTART,
+       /** The post-create/post-remove hook has been started. */
+       HS_POST_RUNNING,
 };
 
 /**
 };
 
 /**
@@ -104,11 +90,11 @@ int complete_name(int64_t start, int64_t end, char **result);
 __malloc char *name_of_newest_complete_snapshot(struct snapshot_list *sl);
 
 /**
 __malloc char *name_of_newest_complete_snapshot(struct snapshot_list *sl);
 
 /**
* Get the oldest snapshot in a snapshot list.
  */
  */
-_static_inline_ struct snapshot *get_oldest_snapshot(struct snapshot_list *sl)
+_static_inline_ struct snapshot *get_newest_snapshot(struct snapshot_list *sl)
 {
        if (!sl->num_snapshots)
                return NULL;
 {
        if (!sl->num_snapshots)
                return NULL;
-       return sl->snapshots[0];
+       return sl->snapshots[sl->num_snapshots - 1];
 }
 }
@@ -104,11 +90,11 @@ int complete_name(int64_t start, int64_t end, char **result);
 
 /**
- * Get the oldest snapshot in a snapshot list.
+ * Get the newest snapshot in a snapshot list.
  */
  */